package com.bonus.zlpt.equip.service.impl;

import java.util.List;

import com.bonus.zlpt.common.core.utils.DateUtils;
import com.bonus.zlpt.equip.api.domain.TypeInfoRecord;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.zlpt.equip.mapper.TypeInfoRecordMapper;
import com.bonus.zlpt.equip.service.ITypeInfoRecordService;

import javax.annotation.Resource;

/**
 * 设备类型Service业务层处理
 * 
 * @author xsheng
 * @date 2023-12-02
 */
@Service
public class TypeInfoRecordServiceImpl implements ITypeInfoRecordService 
{
    @Resource
    private TypeInfoRecordMapper typeInfoRecordMapper;

    /**
     * 查询设备类型
     * 
     * @param typeId 设备类型主键
     * @return 设备类型
     */
    @Override
    public TypeInfoRecord selectTypeInfoRecordByTypeId(Long typeId)
    {
        return typeInfoRecordMapper.selectTypeInfoRecordByTypeId(typeId);
    }

    /**
     * 查询设备类型列表
     * 
     * @param typeInfoRecord 设备类型
     * @return 设备类型
     */
    @Override
    public List<TypeInfoRecord> selectTypeInfoRecordList(TypeInfoRecord typeInfoRecord)
    {
        return typeInfoRecordMapper.selectTypeInfoRecordList(typeInfoRecord);
    }

    /**
     * 新增设备类型
     * 
     * @param typeInfoRecord 设备类型
     * @return 结果
     */
    @Override
    public int insertTypeInfoRecord(TypeInfoRecord typeInfoRecord)
    {
        typeInfoRecord.setCreateTime(DateUtils.getNowDate());
        return typeInfoRecordMapper.insertTypeInfoRecord(typeInfoRecord);
    }

    /**
     * 修改设备类型
     * 
     * @param typeInfoRecord 设备类型
     * @return 结果
     */
    @Override
    public int updateTypeInfoRecord(TypeInfoRecord typeInfoRecord)
    {
        typeInfoRecord.setUpdateTime(DateUtils.getNowDate());
        return typeInfoRecordMapper.updateTypeInfoRecord(typeInfoRecord);
    }

    /**
     * 批量删除设备类型
     * 
     * @param typeIds 需要删除的设备类型主键
     * @return 结果
     */
    @Override
    public int deleteTypeInfoRecordByTypeIds(Long[] typeIds)
    {
        return typeInfoRecordMapper.deleteTypeInfoRecordByTypeIds(typeIds);
    }

    /**
     * 删除设备类型信息
     * 
     * @param typeId 设备类型主键
     * @return 结果
     */
    @Override
    public int deleteTypeInfoRecordByTypeId(Long typeId)
    {
        return typeInfoRecordMapper.deleteTypeInfoRecordByTypeId(typeId);
    }
}
